# Benchmark Set Input Files and Supporting Data

This directory (and its subdirectories) provides structure and simulation input files for benchmark sets proposed in the associated perpetual review paper as well as (in some cases) data on additional supplementary compounds as well.

This file documents what files are present here and how they were generated.

## Manifest
- `BRD4`: BRD4-1 benchmarks as proposed in two Tables in the paper; provides its own `README.md` detailing its organization/contents/provenance.
- `cb7-set1` and `cb7-set2`: Proposed CB7 benchmark sets, with organization/contents/provenance information below.
- `cd-set1` and `cd-set2`: Proposed cyclodextrin benchmark sets (the first of which is on alpha cyclodextrin and the second on beta cyclodextrin), with organization/contents/provenance information below. **Additional, supplementary guests are also provided.** These also contain a machine-parseable `README.md` file with experimental binding free energies and enthalpies, with references.
- `gdcc-set1` and `gdcc-set2`: Proposed Gibb deep cavity cavitand benchmark sets, with organization/contents/provenance information below.

## File Descriptions
This set of files comprises PDB, sdf, and mol2 files for the free hosts and guests, as well as AMBER prmtop/rst7 format input files for the solvated and equilibrated host-guest complexes.
The guest compounds in each set are named according to the compound ID listed in the corresponding Tables in the associated paper [1].
For instance, compound p-toluidine is located in the cb7-set2 subdirectory and named guest-9 because it is included in CB7 Set 2, and its ID in the paper is 9.
The prmtop/rst7 files are named in the same way, except that both the host identifier name and guest ID are used for the filename.
For cd-set1 and cd-set2, there are two sets of prmtop/rst7 files, one for each possible orientation of the guest in the cyclodextrin cavity.
In addition, the cyclodextrin datasets also include files with an 's' character prior to the guest ID number (e.g., bcd-s15.pdb), which indicates that these are supplemental guests not listed in the associated paper which could be of additional interest.

## CB7 Methods
The structures of the free CB7 host were initially obtained from the crystal structure [2] while all other unbound guest structures were built manually.
The structures were then QM energy minimized in vacuo using the HF/6-31G(d) method in Gaussian09.
The CB7 molecule has zero net charge, while the protonation states of the guests were predicted with the pKa plugin in the Marvin suite of programs [3].
Guest guest-18 in cb7-set1 is a special case, because it was predicted to have the protonated and unprotonated forms coexisting at the experimental pH value (4.74) [4] with a nearly 1:1 ratio.
Therefore, files of both forms are provided, with guest-18 as the protonated form of the guest and guest-18b as the unprotonated form.
For the simulation files, bonded and Lennard-Jones parameters were obtained from the general AMBER force field (GAFF v1.7) [5].
Partial charges for each atom were generated using the RESP procedure [6], as implemented in the Antechamber program [7], by fitting to electrostatic potentials grids generated during the QM minimization.
The starting bound configuration of each host-guest pair was generated by docking the guests into the hosts with MOE [8].
The binding pose was then solvated in a cubic box with 1500 TIP3P water molecules with sodium or chloride counterions added only for neutralization.
Counterions were modeled with the TIP3P-specific sodium parameters of Joung and Cheatham [9].
After an equilibration phase, an NVT simulation of 2 ns was carried out, and the frame with the most populated configuration, determined via clustering, was selected as the simulation input file.


## OA/TEMOA (GDCC) Methods
The structures of the free hosts OA and TEMOA, as well as of all unbound guests, were built manually and then QM energy minimized in vacuo using the HF/6-31G(d) method in Gaussin09.
The OA and TEMOA hosts both were assigned net charges of -8au, based on the pH at which the experiments were conducted (9.2 and 11.5) [10, 11].
The protonation states of guests were predicted with the pKa plugin in the Marvin suite of programs [3].
For the simulation files, bonded and LJ force field parameters were taken from GAFF v1.7 and partial charges were determined using the RESP approach, in identical fashion to the CB7 method.
The starting bound configuration of each host-guest pair was generated by docking the guests into the hosts with MOE [8]. 
The binding pose was then solvated in a cubic box with 2100 TIP3P water molecules with sodium or chloride counterions added only for neutralization.
Counterions were modeled with the TIP3P-specific sodium parameters of Joung and Cheatham [9].
After an equilibration phase, an NVT simulation of 2 ns was carried out, and the frame with the most populated configuration, determined via clustering, was selected as the simulation input file.


## CD Methods
The stuctures of unbound alpha-cyclodextrin (aCD) and beta-cyclodextrin (bCD), as well as all guests, were built manually.
Protonation states followed what was reported by Rekharsky et al. [12] at pH 6.9.
The guest molecules were QM energy minimized in vacuo using the HF/6-31G(d) method in Gaussian09.
Partial charges, LJ paramters, and bonded parameters for the CD molecules were taken from the q4md-CD force field by Cézard et al. [13]. 
Guest partial charges were derived using the RESP method implemented in the R.E.D. Server tool [14], while LJ and bonded parameters were taken from GAFF v1.7.
The AMBER simulation files consist of the host-guest complex, 1500 TIP3P waters, and three Na+ and Cl- ions in addition to any counterions required for neutralization.
This roughly corresponds to the ionic strength of the 50 mmol phosphate buffer used in experiment.
The solvated systems were equilibrated in the NPT ensemble with light (0.1 kcal/mol) positional restraints on the host and guest atoms.
The final conformation of this equilibration step is provided here.
Unrestrained equilibration and clustering was not performed for the cyclodextrin sets, in contrast to the CB7 and GDCC sets, because in some cases the guest binds weakly enough that it could leave the binding cavity for significant periods of time.
To account for the two possible orientations of the guest within the CD cavity, simulation files with the '-p' suffix indicate that the guest is bound with the polar functional group oriented out of the primary (narrow) face of the CD, whereas the '-s' suffix indicates the guest polar functional group is oriented out of the secondary (wider) face of the CD.

## BRD4
For information on the BRD4 benchmark, see the associated `README.md` file in the BRD4 subdirectory.

## References
1. Mobley DL, Gilson. MK (2016) Predicting binding free energies: Frontiers and benchmarks. bioRxiv 74625. doi: 10.1101/074625
2. Jeon WS, Moon K, Park SH, et al (2005) Complexation of ferrocene derivatives by the cucurbit[7]uril host: A comparative study of the cucurbituril and cyclodextrin host families. J Am Chem Soc 127:1298412989. doi: 10.1021/ja052912c
3. (2016) ChemAxon Marvin 16.10.31 (www.chemaxon.com/products/marvin).
4. Liu S, Ruspic C, Mukhopadhyay P, et al (2005) The cucurbit[n]uril family: Prime components for self-sorting systems. J Am Chem Soc 127:15959-15967. doi: 10.1021/ja055013x
5. Wang J, Wolf RM, Caldwell JW, et al (2004) Development and Testing of a General Amber Force Field. 25:1157-1174. doi: 10.1002/jcc.20035
6. Bayly CCI, Cieplak P, Cornell WD, Kollman PA (1993) A well-behaved electrostatic potential based method using charge restraints for deriving atomic charges: the RESP model. J Phys Chem 97:10269-10280. doi: 10.1021/j100142a004
7. Case DA, Betz, RM, Botello-Smith W, Cerutti, DS, Cheatham III TE, Darden, TA, Duke RE, Giese TJ, Gohlke H, Goetz AW, Homeyer N, Izadi S, Janowski P, Kaus J, Kovalenko A, Lee TS, LeGrand S, Li P, Lin C, Luchko T, Luo R, Madej B, Mermelstein D, Merz KM, Monard G, Nguyen H, Nguyen HT, Omelyan I, Onufriev A, Roe DR, Roitberg A, Sagui C, Simmerling CL, Swails J, Walker RC, Wang J, Wolf RM, Wu X, Xiao L, York DM, Kollman PA (2016) AMBER 16, University of California, San Francisco
8. Molecular Operating Environment (MOE) 2013.08 (2016) Chemical Computing Group Inc., 1010 Sherbooke St. West, Suite #910, Montreal, QC, Canada, H3A 2R7.
9. Srinivasan J, Cheatham TE, Cieplak P, et al (1998) Continuum solvent studies of the stability of DNA, RNA, and phosphoramidate-DNA helices. J Am Chem Soc 120:9401-9409. doi: 10.1021/ja981844+
10. Gibb CLD, Gibb BC (2014) Binding of cyclic carboxylates to octa-acid deep-cavity cavitand. J Comput Aided Mol Des 28:319-325. doi: 10.1007/s10822-013-9690-2
11. Sullivan MR, Sokkalingam P, Nguyen T, et al (2016) Binding of carboxylate and trimethylammonium salts to octa-acid and TEMOA deep-cavity cavitands. J Comput Aided Mol Des 1-8. doi: 10.1007/s10822-016-9925-0
12. Rekharsky MV, Mayhew MP, Goldberg RN, Ross PD, Yamashoji Y, Inoue Y. (1997) Thermodynamic and nuclear magnetic resonance study of the reactions of α-and β-cyclodextrin with acids, aliphatic amines, and cyclic alcohols. J Phys Chem B. 101(1):87-100. doi: 10.1021/jp962715n
13. Cézard C, Trivelli X, Aubry F, Djedaïni-Pilard F, Dupradeau FY. (2011) Molecular dynamics studies of native and substituted cyclodextrins in different media: 1. Charge derivation and force field performances. Phys Chem Chem Phys. 13(33):15103-21. doi: 10.1039/C1CP20854C
14. Vanquelef E, Simon S, Marquant G, Garcia E, Klimerak G, Delepine JC, Cieplak P, Dupradeau FY. (2011) RED Server: a web service for deriving RESP and ESP charges and building force field libraries for new molecules and molecular fragments. NAR. 39(suppl 2):W511-7. doi: 10.1093/nar/gkr288
